pub struct TouchSlot { /* private fields */ }Expand description
Slot of a different touch event.
Touch events are grouped by slots, usually to identify different fingers on a multi-touch enabled input device. Events should only be interpreted in the context of other events on the same slot.